@@ -1,9 +1,9 @@
-from tcs_protowhat.Feedback import FeedbackComponent
+from protowhat.Feedback import FeedbackComponent
 from tcs_pythonwhat.checks.check_logic import multi
 from tcs_pythonwhat.checks.has_funcs import has_part
-from tcs_protowhat.failure import debugger
-from tcs_pythonwhat.tasks import setUpNewEnvInProcess, breakDownNewEnvInProcess
-from tcs_protowhat.utils_messaging import get_ord
+from protowhat.failure import debugger
+from pythonwhat.tasks import setUpNewEnvInProcess, breakDownNewEnvInProcess
+from protowhat.utils_messaging import get_ord
 from tcs_pythonwhat.utils_ast import assert_ast
 import ast
 from jinja2 import Template
